include: https://salsa.debian.org/salsa-ci-team/pipeline/raw/master/salsa-ci.yml

# end of salsa pipeline bot parser

run autopkgtest:
  script:
    - echo "I duno what to test, if you know. Just let me know or do a MR"
